==> flutterpluginwx-0.0.4.tar.gz: android/src/main/java/com/pl/flutterpluginwx/FlutterpluginwxPlugin.java <==
package com.pl.flutterpluginwx;

import com.pl.flutterpluginwx.handlers.FluwxAuthHandler;
import com.pl.flutterpluginwx.handlers.FluwxShareHandlerEmbedding;
import com.pl.flutterpluginwx.handlers.WXAPiHandler;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import com.tencent.mm.opensdk.modelbiz.SubscribeMessage;
import com.tencent.mm.opensdk.modelbiz.WXLaunchMiniProgram;
import com.tencent.mm.opensdk.modelbiz.WXOpenBusinessWebview;
import com.tencent.mm.opensdk.modelpay.PayReq;

/**
 * FlutterpluginwxPlugin
 */
public class FlutterpluginwxPlugin implements FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private FluwxAuthHandler authHandler = null;
    private FluwxShareHandlerEmbedding shareHandler = null;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "flutterpluginwx");
        channel.setMethodCallHandler(this);
        authHandler = new FluwxAuthHandler(channel);
        shareHandler = new FluwxShareHandlerEmbedding(flutterPluginBinding.getFlutterAssets(), flutterPluginBinding.getApplicationContext());
    }

    // This static function is optional and equivalent to onAttachedToEngine. It supports the old
    // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
    // plugin registration via this function while apps migrate to use the new Android APIs
    // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
    //
    // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
    // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
    // depending on the user's project. onAttachedToEngine or registerWith must both be defined
    // in the same class.
    public static void registerWith(Registrar registrar) {

        final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutterpluginwx");
        channel.setMethodCallHandler(new FlutterpluginwxPlugin());
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equals("registerApp")) {
            WXAPiHandler.INSTANCE.registerApp(call, result);
        } else if (call.method.equals("sendAuth")) {
            if (authHandler != null)
                authHandler.sendAuth(call, result);
        } else if (call.method.equals("authByQRCode")) {
            if (authHandler != null)
                authHandler.authByQRCode(call, result);
        } else if (call.method.equals("stopAuthByQRCode")) {
            if (authHandler != null)
                authHandler.stopAuthByQRCode(result);
        } else if (call.method.equals("payWithFluwx")) {
            pay(call, result);
        } else if (call.method.equals("payWithHongKongWallet")) {
            result.notImplemented();
        } else if (call.method.equals("launchMiniProgram")) {
            result.notImplemented();
        } else if (call.method.equals("subscribeMsg")) {
            result.notImplemented();
        } else if (call.method.equals("autoDeduct")) {
            result.notImplemented();
        } else if (call.method.equals("openWXApp")) {
            openWXApp(result);
        } else if (call.method.startsWith("share")) {
            if (shareHandler != null)
                shareHandler.share(call, result);
        } else if (call.method.equals("isWeChatInstalled")) {
            WXAPiHandler.INSTANCE.checkWeChatInstallation(result);
        } else result.notImplemented();
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    private void pay(MethodCall call, MethodChannel.Result result) {

        if (WXAPiHandler.INSTANCE.getWxApi() == null) {
            result.error("Unassigned WxApi", "please config  wxapi first", null);
        } else {

// 将该app注册到微信
            PayReq request = new PayReq();
            request.appId = call.argument("appId");
            request.partnerId = call.argument("partnerId");
            request.prepayId = call.argument("prepayId");
            request.packageValue = call.argument("packageValue");
            request.nonceStr = call.argument("nonceStr");
            request.timeStamp = call.argument("timeStamp").toString();
            request.sign = call.argument("sign");
            request.signType = call.argument("signType");
            request.extData = call.argument("extData");
            boolean done = WXAPiHandler.INSTANCE.getWxApi().sendReq(request);
            result.success(done);
        }
    }

    private void openWXApp(MethodChannel.Result resul) {
        resul.success(WXAPiHandler.INSTANCE.getWxApi().openWXApp());
    }

}

==> flutterpluginwx-0.0.5.tar.gz: android/src/main/java/com/pl/flutterpluginwx/FlutterpluginwxPlugin.java <==
package com.pl.flutterpluginwx;

import com.pl.flutterpluginwx.handlers.FluwxAuthHandler;
import com.pl.flutterpluginwx.handlers.FluwxShareHandlerEmbedding;
import com.pl.flutterpluginwx.handlers.PermissionHandler;
import com.pl.flutterpluginwx.handlers.WXAPiHandler;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import com.tencent.mm.opensdk.modelbiz.SubscribeMessage;
import com.tencent.mm.opensdk.modelbiz.WXLaunchMiniProgram;
import com.tencent.mm.opensdk.modelbiz.WXOpenBusinessWebview;
import com.tencent.mm.opensdk.modelpay.PayReq;

/**
 * FlutterpluginwxPlugin
 */
public class FlutterpluginwxPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private FluwxAuthHandler authHandler = null;
    private FluwxShareHandlerEmbedding shareHandler = null;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "flutterpluginwx");
        channel.setMethodCallHandler(this);
        authHandler = new FluwxAuthHandler(channel);
        shareHandler = new FluwxShareHandlerEmbedding(flutterPluginBinding.getFlutterAssets(), flutterPluginBinding.getApplicationContext());
        WXAPiHandler.INSTANCE.setContext(flutterPluginBinding.getApplicationContext());
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

    }

    @Override
    public void onDetachedFromActivity() {

    }

    // This static function is optional and equivalent to onAttachedToEngine. It supports the old
    // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
    // plugin registration via this function while apps migrate to use the new Android APIs
    // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
    //
    // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
    // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
    // depending on the user's project. onAttachedToEngine or registerWith must both be defined
    // in the same class.
    public static void registerWith(Registrar registrar) {

        final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutterpluginwx");
        channel.setMethodCallHandler(new FlutterpluginwxPlugin());
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equals("registerApp")) {
            WXAPiHandler.INSTANCE.registerApp(call, result);
        } else if (call.method.equals("sendAuth")) {
            if (authHandler != null)
                authHandler.sendAuth(call, result);
        } else if (call.method.equals("authByQRCode")) {
            if (authHandler != null)
                authHandler.authByQRCode(call, result);
        } else if (call.method.equals("stopAuthByQRCode")) {
            if (authHandler != null)
                authHandler.stopAuthByQRCode(result);
        } else if (call.method.equals("payWithFluwx")) {
            pay(call, result);
        } else if (call.method.equals("payWithHongKongWallet")) {
            result.notImplemented();
        } else if (call.method.equals("launchMiniProgram")) {
            result.notImplemented();
        } else if (call.method.equals("subscribeMsg")) {
            result.notImplemented();
        } else if (call.method.equals("autoDeduct")) {
            result.notImplemented();
        } else if (call.method.equals("openWXApp")) {
            openWXApp(result);
        } else if (call.method.startsWith("share")) {
            if (shareHandler != null)
                shareHandler.share(call, result);
        } else if (call.method.equals("isWeChatInstalled")) {
            WXAPiHandler.INSTANCE.checkWeChatInstallation(result);
        } else result.notImplemented();
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
        if(shareHandler!=null)shareHandler.onDestroy();
        if(authHandler!=null)shareHandler.removeAllListeners();
    }

    private void pay(MethodCall call, MethodChannel.Result result) {

        if (WXAPiHandler.INSTANCE.getWxApi() == null) {
            result.error("Unassigned WxApi", "please config  wxapi first", null);
        } else {

// 将该app注册到微信
            PayReq request = new PayReq();
            request.appId = call.argument("appId");
            request.partnerId = call.argument("partnerId");
            request.prepayId = call.argument("prepayId");
            request.packageValue = call.argument("packageValue");
            request.nonceStr = call.argument("nonceStr");
            request.timeStamp = call.argument("timeStamp").toString();
            request.sign = call.argument("sign");
            request.signType = call.argument("signType");
            request.extData = call.argument("extData");
            boolean done = WXAPiHandler.INSTANCE.getWxApi().sendReq(request);
            result.success(done);
        }
    }

    private void openWXApp(MethodChannel.Result resul) {
        resul.success(WXAPiHandler.INSTANCE.getWxApi().openWXApp());
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        WXAPiHandler.INSTANCE.setContext(binding.getActivity().getApplicationContext());
        if (shareHandler != null) {
            shareHandler.setPermissionHandler(new PermissionHandler(binding.getActivity()));
        }
    }
}
